diff --git a/core/modules/views/lib/Drupal/views/Plugin/views/filter/InOperator.php b/core/modules/views/lib/Drupal/views/Plugin/views/filter/InOperator.php
index 84d8723..fb70a6b 100644
--- a/core/modules/views/lib/Drupal/views/Plugin/views/filter/InOperator.php
+++ b/core/modules/views/lib/Drupal/views/Plugin/views/filter/InOperator.php
@@ -23,22 +23,27 @@
  */
 class InOperator extends FilterPluginBase {
 
-  var $value_form_type = 'checkboxes';
+  /**
+   * Determine the type of form element.
+   *
+   * @var string
+   */
+  protected $valueFormType = 'checkboxes';
 
   /**
-   * @var array
    * Stores all operations which are available on the form.
+   *
+   * @var array
    */
-  var $value_options = NULL;
+  protected $valueOptions = NULL;
 
   /**
    * Overrides \Drupal\views\Plugin\views\filter\FilterPluginBase::init().
    */
   public function init(ViewExecutable $view, DisplayPluginBase $display, array &$options = NULL) {
     parent::init($view, $display, $options);
-
-    $this->value_title = t('Options');
-    $this->value_options = NULL;
+    $this->valueTitle = t('Options');
+    $this->valueOptions = NULL;
   }
 
   /**
@@ -50,26 +55,26 @@ public function init(ViewExecutable $view, DisplayPluginBase $display, array &$o
    * possible.
    *
    * @return
    *   Return the stored values in $this->value_options if someone expects it.
    */
   public function getValueOptions() {
-    if (isset($this->value_options)) {
+    if (isset($this->valueOptions)) {
       return;
     }
 
     if (isset($this->definition['options callback']) && is_callable($this->definition['options callback'])) {
       if (isset($this->definition['options arguments']) && is_array($this->definition['options arguments'])) {
-        $this->value_options = call_user_func_array($this->definition['options callback'], $this->definition['options arguments']);
+        $this->valueOptions = call_user_func_array($this->definition['options callback'], $this->definition['options arguments']);
       }
       else {
-        $this->value_options = call_user_func($this->definition['options callback']);
+        $this->valueOptions = call_user_func($this->definition['options callback']);
       }
     }
     else {
-      $this->value_options = array(t('Yes'), t('No'));
+      $this->valueOptions = array(t('Yes'), t('No'));
     }
 
-    return $this->value_options;
+    return $this->valueOptions;
   }
 
   public function defaultExposeOptions() {
@@ -173,7 +178,7 @@ protected function valueForm(&$form, &$form_state) {
     }
 
     $this->getValueOptions();
-    $options += $this->value_options;
+    $options += $this->valueOptions;
     $default_value = (array) $this->value;
 
     $which = 'all';
@@ -216,8 +221,8 @@ protected function valueForm(&$form, &$form_state) {
 
     if ($which == 'all' || $which == 'value') {
       $form['value'] = array(
-        '#type' => $this->value_form_type,
-        '#title' => $this->value_title,
+        '#type' => $this->valueFormType,
+        '#title' => $this->valueTitle,
         '#options' => $options,
         '#default_value' => $default_value,
         // These are only valid for 'select' type, but do no harm to checkboxes.
@@ -229,7 +234,7 @@ protected function valueForm(&$form, &$form_state) {
       }
 
       if ($which == 'all') {
-        if (empty($form_state['exposed']) && (in_array($this->value_form_type, array('checkbox', 'checkboxes', 'radios', 'select')))) {
+        if (empty($form_state['exposed']) && (in_array($this->valueFormType, array('checkbox', 'checkboxes', 'radios', 'select')))) {
           $form['value']['#prefix'] = '<div id="edit-options-value-wrapper">';
           $form['value']['#suffix'] = '</div>';
         }
@@ -248,7 +253,7 @@ protected function valueForm(&$form, &$form_state) {
    */
   public function reduceValueOptions($input = NULL) {
     if (!isset($input)) {
-      $input = $this->value_options;
+      $input = $this->valueOptions;
     }
 
     // Because options may be an array of strings, or an array of mixed arrays
@@ -326,7 +331,7 @@ public function adminSummary() {
     if (in_array($this->operator, $this->operatorValues(1))) {
       // Remove every element which is not known.
       foreach ($this->value as $value) {
-        if (!isset($this->value_options[$value])) {
+        if (!isset($this->valueOptions[$value])) {
           unset($this->value[$value]);
         }
       }
@@ -342,8 +347,8 @@ public function adminSummary() {
 
         $keys = $this->value;
         $value = array_shift($keys);
-        if (isset($this->value_options[$value])) {
-          $values = check_plain($this->value_options[$value]);
+        if (isset($this->valueOptions[$value])) {
+          $values = check_plain($this->valueOptions[$value]);
         }
         else {
           $values = '';
@@ -358,8 +363,8 @@ public function adminSummary() {
             $values .= '...';
             break;
           }
-          if (isset($this->value_options[$value])) {
-            $values .= check_plain($this->value_options[$value]);
+          if (isset($this->valueOptions[$value])) {
+            $values .= check_plain($this->valueOptions[$value]);
           }
         }
       }
@@ -412,7 +417,7 @@ public function validate() {
       $errors[] = t('The operator is invalid on filter: @filter.', array('@filter' => $this->adminLabel(TRUE)));
     }
     if (is_array($this->value)) {
-      if (!isset($this->value_options)) {
+      if (!isset($this->valueOptions)) {
         // Don't validate if there are none value options provided, for example for special handlers.
         return $errors;
       }
@@ -422,7 +427,7 @@ public function validate() {
       }
 
       // Some filter_in_operator usage uses optgroups forms, so flatten it.
-      $flat_options = form_options_flatten($this->value_options, TRUE);
+      $flat_options = form_options_flatten($this->valueOptions, TRUE);
 
       // Remove every element which is not known.
       foreach ($this->value as $value) {
@@ -50,26 +55,26 @@ public function init(ViewExecutable $view, DisplayPluginBase $display, array &$o
    *
    * @return
-   *   Return the stored values in $this->value_options if someone expects it.
+   *   Return the stored values in $this->valueOptions if someone expects it.
    */
   public function getValueOptions() {
